==> hyperdiv-0.0.1-py3-none-any.whl: hyperdiv/components/uilist.py <==
from .box import box
from .. import elements as el
from .combo import combo


class uilist(combo):
    """
    A uilist is a list with a customizable
    bullet, title, subtitle, and trailing content (e.g icon)

    Like this:
    (*) title here          trailing
        subtitle            content

    (*) title here          trailing
        subtitle            content

    The formatter is an object that describes how to render
    an item. It should implement the methods:
    * id(item) -> unique id (str, int)
    * title(item) -> str or element
    * subtitle(item) -> str or element
    * bullet -> element
    * trailing_content -> hd.Icons or element
    """

    def __init__(self, items, formatter, **box_props):
        s = el.state(selected=None)

        with box(**box_props) as self._listbox:
            for i in items:
                itemid = formatter.id(i)
                with el.scope(itemid):
                    li = uilist_item(
                        i,
                        formatter,
                        selected=s.selected and formatter.id(s.selected) == itemid,
                    )
                    if li.clicked:
                        s.selected = i
        super().__init__(self._listbox, s, changed_props=["selected"])


class uilist_item(combo):
    def __init__(self, item, formatter, selected=False):
        if selected:
            background_color = el.highlight(el.theme().background_color, 30)
        else:
            background_color = None

        with el.container(
            layout="grid",
            grid_template_columns=("auto", "1fr", "auto"),
            grid_template_areas=(
                ("bullet-top", "title", "trailing-content"),
                ("bullet-bottom", "subtitle", "trailing-content"),
            ),
            background_color=background_color,
            cursor="pointer",
            padding=8,
            gap=(2, 4),
        ) as li:
            with box(justify="center", grid_area="bullet-top"):
                try:
                    formatter.bullet(item)
                except Exception:
                    pass

            with box(justify="center", grid_area="title"):
                try:
                    title = formatter.title(item)
                    if isinstance(title, str):
                        el.text(title)
                except Exception:
                    pass

            with box(grid_area="subtitle"):
                try:
                    subtitle = formatter.subtitle(item)
                    if isinstance(subtitle, str):
                        el.text(
                            formatter.subtitle(item),
                            font_size="small",
                            font_color=el.highlight(el.theme().font_color, 150),
                        )
                except Exception:
                    pass

            with box(grid_area="trailing-content", justify="center"):
                try:
                    trailing = formatter.trailing_content(item)
                    if isinstance(trailing, el.Icons):
                        el.icon(trailing)
                except Exception:
                    pass

        super().__init__(li)

==> hyperdiv-0.0.4-py3-none-any.whl: hyperdiv/components/uilist.py <==
from .. import elements as el
from .combo import combo


class uilist(combo):
    """
    A uilist is a list with a customizable
    bullet, title, subtitle, and trailing content (e.g icon)

    Like this:
    (*) title here          trailing
        subtitle            content

    (*) title here          trailing
        subtitle            content

    The formatter is an object that describes how to render
    an item. It should implement the methods:
    * id(item) -> unique id (str, int)
    * title(item) -> str or element
    * subtitle(item) -> str or element
    * bullet -> element
    * trailing_content -> hd.Icons or element
    """

    def __init__(self, items, formatter, **box_props):
        s = el.state(selected=None)

        with el.box(**box_props) as self._listbox:
            for i in items:
                itemid = formatter.id(i)
                with el.scope(itemid):
                    li = uilist_item(
                        i,
                        formatter,
                        selected=s.selected and formatter.id(s.selected) == itemid,
                    )
                    if li.clicked:
                        s.selected = i
        super().__init__(self._listbox, s, changed_props=["selected"])


class uilist_item(combo):
    def __init__(self, item, formatter, selected=False):
        if selected:
            background_color = el.highlight(el.theme().background_color, 30)
        else:
            background_color = None

        with el.container(
            layout="grid",
            grid_template_columns=("auto", "1fr", "auto"),
            grid_template_areas=(
                ("bullet-top", "title", "trailing-content"),
                ("bullet-bottom", "subtitle", "trailing-content"),
            ),
            background_color=background_color,
            cursor="pointer",
            padding=8,
            gap=(2, 4),
        ) as li:
            with el.box(justify="center", grid_area="bullet-top"):
                try:
                    formatter.bullet(item)
                except Exception:
                    pass

            with el.box(justify="center", grid_area="title"):
                try:
                    title = formatter.title(item)
                    if isinstance(title, str):
                        el.text(title)
                except Exception:
                    pass

            with el.box(grid_area="subtitle"):
                try:
                    subtitle = formatter.subtitle(item)
                    if isinstance(subtitle, str):
                        el.text(
                            formatter.subtitle(item),
                            font_size="small",
                            font_color=el.highlight(el.theme().font_color, 150),
                        )
                except Exception:
                    pass

            with el.box(grid_area="trailing-content", justify="center"):
                try:
                    trailing = formatter.trailing_content(item)
                    if isinstance(trailing, el.Icons):
                        el.icon(trailing)
                except Exception:
                    pass

        super().__init__(li)
